@@ -1,7 +1,9 @@
 /***************************************************************************
     begin                : Sat Jun 7 2003
-    copyright            : (C) 2003 - 2004 by Scott Wheeler, 
+    copyright            : (C) 2003 - 2004 by Scott Wheeler,
     email                : wheeler@kde.org
+    copyright            : (c) 2007 Michael Pyne
+    email                : michael.pyne@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -16,15 +18,15 @@
 #ifndef VIEWMODE_H
 #define VIEWMODE_H
 
-
-#include <qdict.h>
+#include <QObject>
+#include <QStringList>
+#include <QMap>
 
 #include "playlistbox.h"
 
 class QPainter;
 class QColorGroup;
 
-class SearchPlaylist;
 
 class ViewMode : public QObject
 {
@@ -34,21 +36,47 @@ public:
     ViewMode(PlaylistBox *b);
     virtual ~ViewMode();
 
-    virtual QString name() const { return i18n("Default"); }
+    virtual QString name() const;
     virtual void setShown(bool shown);
 
     virtual void paintCell(PlaylistBox::Item *item,
-                           QPainter *painter, 
+                           QPainter *painter,
                            const QColorGroup &colorGroup,
                            int column, int width, int align);
 
     virtual bool eventFilter(QObject *watched, QEvent *e);
-    
-
     void queueRefresh() { m_needsRefresh = true; }
 
     virtual void setupItem(PlaylistBox::Item *item) const;
 
+    virtual void setupDynamicPlaylists() {}
+
+    /**
+     * If the view mode has dynamic lists, this function is used to temporarily
+     * freeze them to prevent them from deleting dynamic elements.
+     */
+    virtual void setDynamicListsFrozen(bool /* frozen */) {}
+
+    /**
+     * Used for dynamic view modes.  This function will be called when \p items
+     * are added to \p column (even if the view mode hasn't been shown yet).
+     */
+    virtual void addItems(const QStringList &items, unsigned column)
+    {
+        Q_UNUSED(items);
+        Q_UNUSED(column);
+    }
+
+    /**
+     * Used for dynamic view modes.  This function will be called when \p item
+     * is removed from \p column (even if the view mode hasn't been shown yet).
+     */
+    virtual void removeItem(const QString &item, unsigned column)
+    {
+        Q_UNUSED(item);
+        Q_UNUSED(column);
+    }
+
 protected:
     PlaylistBox *playlistBox() const { return m_playlistBox; }
     bool visible() const { return m_visible; }
@@ -74,8 +102,8 @@ class CompactViewMode : public ViewMode
 public:
     CompactViewMode(PlaylistBox *b);
     virtual ~CompactViewMode();
-    
-    virtual QString name() const { return i18n("Compact"); }
+
+    virtual QString name() const;
     virtual void setShown(bool shown);
 
     virtual void paintCell(PlaylistBox::Item *item,
@@ -83,7 +111,7 @@ public:
                            const QColorGroup &colorGroup,
                            int column, int width, int align);
 
-    virtual void setupItem(PlaylistBox::Item *item) const { item->KListViewItem::setup(); }
+    virtual void setupItem(PlaylistBox::Item *item) const { item->K3ListViewItem::setup(); }
 protected:
     virtual void updateHeights();
 };
@@ -100,24 +128,25 @@ public:
     TreeViewMode(PlaylistBox *l);
     virtual ~TreeViewMode();
 
-    virtual QString name() const { return i18n("Tree"); }
+    virtual QString name() const;
     virtual void setShown(bool shown);
-    void setupCategories();
+    virtual void setupDynamicPlaylists();
+    virtual void setDynamicListsFrozen(bool frozen);
 
-public slots:
-    void slotRemoveItem(const QString &item, unsigned column);
-    void slotAddItems(const QStringList &items, unsigned column);
-
-    void slotCanDeletePlaylist(bool canDelete);
+    virtual void removeItem(const QString &item, unsigned column);
+    virtual void addItems(const QStringList &items, unsigned column);
 
 signals:
     void signalPlaylistDestroyed(Playlist*);
 
 private:
-    QDict<PlaylistBox::Item> m_searchCategories;    
-    QDict<TreeViewItemPlaylist> m_treeViewItems;
+    QMap<QString, PlaylistBox::Item*> m_searchCategories;
+    QMap<QString, TreeViewItemPlaylist*> m_treeViewItems;
     QStringList m_pendingItemsToRemove;
-    bool m_canDeletePlaylists;
+    bool m_dynamicListsFrozen;
+    bool m_setup;
 };
 
 #endif
+
+// vim: set et sw=4 tw=0 sta:
