@@ -65,10 +65,6 @@ Mixer_OSS4::~Mixer_OSS4()
 	close();
 }
 
-void Mixer_OSS4::setRecsrcHW(const QString& id, bool on)
-{
-}
-
 //classifies mixexts according to their name, last classification wins
 MixDevice::ChannelType Mixer_OSS4::classifyAndRename(QString &name, int flags)
 {
@@ -244,7 +240,7 @@ int Mixer_OSS4::open()
 
 			if ( wrapIoctl( ioctl (m_fd, SNDCTL_MIX_NREXT, &m_numExtensions) ) < 0 )
 			{
-				//TODO: more specific error handling here
+				//TO DO: more specific error handling here
 				return Mixer::ERR_READ;
 			}
 
@@ -335,7 +331,8 @@ int Mixer_OSS4::open()
 						chMask = Volume::MLEFT;
 					}
 
-					Volume vol (chMask, ext.maxvalue, ext.minvalue, false, isCapture);
+					Volume vol (ext.maxvalue, ext.minvalue, false, isCapture);
+					vol.addVolumeChannels(chMask);
 
 					MixDevice* md =	new MixDevice(_mixer,
 									QString::number(i),
@@ -368,7 +365,8 @@ int Mixer_OSS4::open()
 				else if ( ext.type == MIXT_HEXVALUE )
 				{
 					chMask = Volume::ChannelMask(Volume::MLEFT);
-					Volume vol (chMask, ext.maxvalue, ext.minvalue, false, isCapture);
+					Volume vol (ext.maxvalue, ext.minvalue, false, isCapture);
+					vol.addVolumeChannels(chMask);
 
 					MixDevice* md =	new MixDevice(_mixer,
 								      QString::number(i),
@@ -398,7 +396,7 @@ int Mixer_OSS4::open()
 #endif
 					)
 				{
-					Volume vol(Volume::MNONE, 1, 0, true, isCapture);
+					Volume vol(1, 0, true, isCapture);
 					
 					if (isCapture)
 						 vol.setSwitchType (Volume::CaptureSwitch);
@@ -430,8 +428,9 @@ int Mixer_OSS4::open()
 
 					if ( wrapIoctl( ioctl (m_fd, SNDCTL_MIX_ENUMINFO, &ei) ) != -1 )
 					{
-						Volume vol(Volume::MLEFT, ext.maxvalue, ext.minvalue,
+						Volume vol(ext.maxvalue, ext.minvalue,
 									false, isCapture);
+						vol.addVolumeChannel(VolumeChannel(Volume::MLEFT));
 
 						MixDevice* md = new MixDevice (_mixer,
 						                               QString::number(i),
@@ -537,7 +536,7 @@ int Mixer_OSS4::readVolumeFromHW(const QString& id, MixDevice *md)
 
 	if ( wrapIoctl( ioctl(m_fd, SNDCTL_MIX_EXTINFO, &extinfo) ) < 0 )
 	{
-		//TODO: more specific error handling
+		//TO DO: more specific error handling
 		return Mixer::ERR_READ;
 	}
 
@@ -605,7 +604,7 @@ int Mixer_OSS4::writeVolumeToHW(const QString& id, MixDevice *md)
 
 	if ( wrapIoctl( ioctl(m_fd, SNDCTL_MIX_EXTINFO, &extinfo) ) < 0 )
 	{
-		//TODO: more specific error handling
+		//TO DO: more specific error handling
 		kDebug ( 67100 ) << "failed to read info for control " << id2num(id) << endl;
 		return Mixer::ERR_READ;
 	}
@@ -622,23 +621,23 @@ int Mixer_OSS4::writeVolumeToHW(const QString& id, MixDevice *md)
 			break;
 
 		case MIXT_MONOSLIDER:
-			volume = vol[Volume::LEFT];
+			volume = vol.getVolume(Volume::LEFT);
 			break;
 
 		case MIXT_STEREOSLIDER:
-			volume = vol[Volume::LEFT] | ( vol[Volume::RIGHT] << 8 );
+			volume = vol.getVolume(Volume::LEFT) | ( vol.getVolume(Volume::RIGHT) << 8 );
 			break;
 
 		case MIXT_SLIDER:
-			volume = vol[Volume::LEFT];
+			volume = vol.getVolume(Volume::LEFT);
 			break;
 
 		case MIXT_MONOSLIDER16:
-			volume = vol[Volume::LEFT];
+			volume = vol.getVolume(Volume::LEFT);
 			break;
 
 		case MIXT_STEREOSLIDER16:
-			volume = vol[Volume::LEFT] | ( vol[Volume::RIGHT] << 16 );
+			volume = vol.getVolume(Volume::LEFT) | ( vol.getVolume(Volume::RIGHT) << 16 );
 			break;
 		default:
 			return -1;
@@ -667,7 +666,7 @@ void Mixer_OSS4::setEnumIdHW(const QString& id, unsigned int idx)
 
 	if ( wrapIoctl ( ioctl(m_fd, SNDCTL_MIX_EXTINFO, &extinfo) ) < 0 )
 	{
-		//TODO: more specific error handling
+		//TO DO: more specific error handling
 		kDebug ( 67100 ) << "failed to read info for control " << id2num(id) << endl;
 		return;
 	}
@@ -715,8 +714,8 @@ unsigned int Mixer_OSS4::enumIdHW(const QString& id)
 
 	if ( wrapIoctl ( ioctl(m_fd, SNDCTL_MIX_EXTINFO, &extinfo) ) < 0 )
 	{
-		//TODO: more specific error handling
-		//TODO: check whether those return values are actually possible
+		//TO DO: more specific error handling
+		//TO DO: check whether those return values are actually possible
 		return Mixer::ERR_READ;
 	}
 
