@@ -64,19 +64,30 @@ KMixDockWidget::KMixDockWidget(KMixWindow* parent, bool volumePopup)
     , _contextMenuWasOpen(false)
 {
     setToolTipIconByName("kmix");
+    setTitle(i18n( "Volume Control"));
     setCategory(Hardware);
     setStatus(Active);
     m_mixer = Mixer::getGlobalMasterMixer();  // ugly, but we'll live with that for now
     createMasterVolWidget();
     createActions();
-    connect(this, SIGNAL(scrollRequested(int,Qt::Orientation)), this, SLOT(trayWheelEvent(int)));
+    connect(this, SIGNAL(scrollRequested(int,Qt::Orientation)), this, SLOT(trayWheelEvent(int,Qt::Orientation)));
     connect(this, SIGNAL(secondaryActivateRequested(QPoint)), this, SLOT(dockMute()));
-    connect(this, SIGNAL(activateRequested(bool, QPoint)), this, SLOT(activateMenuOrWindow(bool, QPoint)));
-    connect(contextMenu(), SIGNAL(aboutToShow()), this, SLOT(contextMenuAboutToShow()));
+
+    bool NO_MENU_ANYMORE = true; 
+    
+    if ( NO_MENU_ANYMORE )
+    {
+      connect(contextMenu(), SIGNAL(aboutToShow()), this, SLOT(activateMenuOrWindow(bool,QPoint)));
+    }
+    else
+    {
+      connect(this, SIGNAL(activateRequested(bool,QPoint)), this, SLOT(activateMenuOrWindow(bool,QPoint)));
+      connect(contextMenu(), SIGNAL(aboutToShow()), this, SLOT(contextMenuAboutToShow()));
+    }
 
 #ifdef _GNU_SOURCE
-// TODO minimizeRestore usage is currently VERY broken
-#warning minimizeRestore usage is currently VERY broken in KMIx. This must be fixed before doing a release.
+// TODO minimizeRestore usage is currently a bit broken. It only works by chance
+#warning minimizeRestore usage is currently slightly broken in KMIx. This should be fixed before doing a release.
 #endif
 
     if (_volumePopup) {
@@ -84,6 +95,7 @@ KMixDockWidget::KMixDockWidget(KMixWindow* parent, bool volumePopup)
         _referenceWidget = new KMenu(parent);
         ViewDockAreaPopup* _referenceWidget2 = new ViewDockAreaPopup(_referenceWidget, "dockArea", Mixer::getGlobalMasterMixer(), 0, (GUIProfile*)0, parent);
         _referenceWidget2->createDeviceWidgets();
+        connect(_referenceWidget2, SIGNAL(recreateMe()), _kmixMainWindow, SLOT(recreateDockWidget()));
 
         _volWA = new QWidgetAction(_referenceWidget);
         _volWA->setDefaultWidget(_referenceWidget2);
@@ -91,6 +103,8 @@ KMixDockWidget::KMixDockWidget(KMixWindow* parent, bool volumePopup)
 
         //setAssociatedWidget(_referenceWidget);
         //setAssociatedWidget(_referenceWidget);  // If you use the popup, associate that instead of the MainWindow
+	
+	//setContextMenu(_referenceWidget2);
     }
     else {
         _volWA = 0;
@@ -112,13 +126,13 @@ KMixDockWidget::~KMixDockWidget()
 void KMixDockWidget::createActions()
 {
    QMenu *menu = contextMenu();
-
+   
    MixDevice* md = Mixer::getGlobalMasterMD();
   if ( md != 0 && md->playbackVolume().hasSwitch() ) {
     // Put "Mute" selector in context menu
     KToggleAction *action = actionCollection()->add<KToggleAction>( "dock_mute" );
     action->setText( i18n( "M&ute" ) );
-    connect(action, SIGNAL(triggered(bool) ), SLOT( dockMute() ));
+    connect(action, SIGNAL(triggered(bool)), SLOT(dockMute()));
     menu->addAction( action );
 }
 
@@ -126,7 +140,7 @@ void KMixDockWidget::createActions()
   if ( m_mixer != 0 ) {
   QAction *action = actionCollection()->addAction( "select_master" );
   action->setText( i18n("Select Master Channel...") );
-  connect(action, SIGNAL(triggered(bool) ), SLOT(selectMaster()));
+  connect(action, SIGNAL(triggered(bool)), SLOT(selectMaster()));
   menu->addAction( action );
   }
 
@@ -168,16 +182,16 @@ KMixDockWidget::createMasterVolWidget()
      * Refreshing the Icon
      */
     //    connect( m_mixer, SIGNAL(controlChanged()), _dockAreaPopup, SLOT(refreshVolumeLevels()) );
-    connect( m_mixer, SIGNAL(controlChanged()), this, SLOT(setVolumeTip() ) );
-    connect( m_mixer, SIGNAL(controlChanged()), this, SLOT(updatePixmap() ) );
+    connect( m_mixer, SIGNAL(controlChanged()), this, SLOT(setVolumeTip()) );
+    connect( m_mixer, SIGNAL(controlChanged()), this, SLOT(updatePixmap()) );
 }
 
 void KMixDockWidget::selectMaster()
 {
    DialogSelectMaster* dsm = new DialogSelectMaster(m_mixer);
    dsm->setAttribute(Qt::WA_DeleteOnClose, true);
-   connect ( dsm, SIGNAL(newMasterSelected(QString&, QString&)), SLOT( handleNewMaster(QString&, QString&)) );
-   connect ( dsm, SIGNAL(newMasterSelected(QString&, QString&)), SIGNAL( newMasterSelected()) );
+   connect ( dsm, SIGNAL(newMasterSelected(QString&,QString&)), SLOT(handleNewMaster(QString&,QString&)) );
+   connect ( dsm, SIGNAL(newMasterSelected(QString&,QString&)), SIGNAL(newMasterSelected()) );
    dsm->show();
 }
 
@@ -210,13 +224,13 @@ KMixDockWidget::setVolumeTip()
     {
         // Playback volume will be used for the DockIcon if available.
         // This heuristic is "good enough" for the DockIcon for now.
-        long val = 0;
+        int val = 0;
         Volume& vol       = md->playbackVolume();
         if (! vol.hasVolume() ) {
            vol = md->captureVolume();
         }
-        if ( vol.hasVolume() && vol.maxVolume() != 0 ) {
-            val = (vol.getAvgVolume(Volume::MMAIN)*100 )/( vol.maxVolume() );
+        if ( vol.hasVolume() ) {
+            val = vol.getAvgVolumePercent(Volume::MALL);
         }
 
         // create a new "virtual" value. With that we see "volume changes" as well as "muted changes"
@@ -258,8 +272,7 @@ KMixDockWidget::updatePixmap()
         if (! vol.hasVolume() ) {
             vol = md->captureVolume();
         }
-        long absoluteVolume    = vol.getAvgVolume(Volume::MALL);
-        int percentage         = vol.percentage(absoluteVolume);
+        int percentage         = vol.getAvgVolumePercent(Volume::MALL);
         if      ( percentage <= 0 ) newPixmapType = '0';  // Hint: also negative-values
         else if ( percentage < 25 ) newPixmapType = '1';
         else if ( percentage < 75 ) newPixmapType = '2';
@@ -371,37 +384,38 @@ void KMixDockWidget::activate(const QPoint &pos)
 // }
 
 void
-KMixDockWidget::trayWheelEvent(int delta)
+KMixDockWidget::trayWheelEvent(int delta,Qt::Orientation wheelOrientation)
 {
   MixDevice *md = Mixer::getGlobalMasterMD();
   if ( md != 0 )
   {
-      Volume vol = md->playbackVolume();
-      if ( md->playbackVolume().hasVolume() )
-         vol = md->playbackVolume();
-      else
-         vol = md->captureVolume();
-
-      int inc = vol.maxVolume() / 20;
+      Volume &vol = ( md->playbackVolume().hasVolume() ) ?  md->playbackVolume() : md->captureVolume();
+      int inc = vol.volumeSpan() / Mixer::VOLUME_STEP_DIVISOR;
 
     if ( inc < 1 ) inc = 1;
 
-    for ( int i = 0; i < vol.count(); i++ ) {
-        int newVal = vol[i] + (inc * (delta / 120));
-        if( newVal < 0 ) newVal = 0;
-        vol.setVolume( (Volume::ChannelID)i, newVal < vol.maxVolume() ? newVal : vol.maxVolume() );
-    }
+    if (wheelOrientation == Qt::Horizontal) // Reverse horizontal scroll: bko228780 
+    	delta = -delta;
+
+    long int cv = inc * (delta / 120 );
+//    kDebug() << "twe: " << cv << " : " << vol;
+	if ( cv > 0 && md->isMuted())
+	{   // increasing from muted state: unmute and start with a low volume level
+	    md->setMuted(false);
+	    vol.setAllVolumes(cv);
+	}
+	else
+	    vol.changeAllVolumes(cv);
+
+//	kDebug() << "twe: " << cv << " : " << vol;
 
     if ( _playBeepOnVolumeChange ) {
         QString fileName("KDE_Beep_Digital_1.ogg");
         _audioPlayer->setCurrentSource(fileName);
         _audioPlayer->play();
     }
-      if ( md->playbackVolume().hasVolume() )
-         md->playbackVolume().setVolume(vol);
-      else
-         md->captureVolume().setVolume(vol);
-    m_mixer->commitVolumeChange(md);
+
+    md->mixer()->commitVolumeChange(md);
     setVolumeTip();
   }
 }
@@ -437,7 +451,7 @@ KMixDockWidget::contextMenuAboutToShow()
         }
         kDebug() << "<<< mm 3";
         //disconnect(showAction, 0, 0, 0);
-        //connect(showAction, SIGNAL(triggered(bool), this, hideOrShowMainWindow() );
+        //connect(showAction, SIGNAL(triggered(bool),this,hideOrShowMainWindow());
     }
     */
 
