@@ -22,8 +22,9 @@
 #define ViewBase_h
 
 // QT
+#include <QSet>
 #include <QWidget>
-#include <qlist.h>
+#include <QList>
 
 // KDE
 #include <KActionCollection>
@@ -88,8 +89,9 @@ public:
     virtual void createDeviceWidgets();
 
     void setMixSet();
+    int visibleControls();
     
-    Mixer* getMixer();
+    bool isDynamic() const;
 
     /**
      * Creates a suitable representation for the given MixDevice.
@@ -112,6 +114,8 @@ public:
    GUIProfile* guiProfile() { return _guiprof; };
    KActionCollection* actionCollection() { return _actions; };
 
+   QSet<Mixer*>& getMixers() { return _mixers; };
+
     /**
      * Contains the widgets for the _mixSet. There is a 1:1 relationship, which means:
      * _mdws[i] is the Widget for the MixDevice _mixSet[i] - please see ViewBase::createDeviceWidgets().
@@ -122,12 +126,13 @@ public:
 
 signals:
     void rebuildGUI();
-    void redrawMixer( const QString& mixer_ID );
+    //void redrawMixer( const QString& mixer_ID );
 
 
 protected:
     MixSet *_mixSet;
     Mixer *_mixer;
+    QSet<Mixer*> _mixers; // this might deprecate _mixer in the future. Currently only in use by ViewDockAreaPopup
     KMenu *_popMenu;
     KActionCollection* _actions; // -<- applciations wide action collection
 
