@@ -44,10 +44,12 @@
 ViewDockAreaPopup::ViewDockAreaPopup(QWidget* parent, const char* name, Mixer* mixer, ViewBase::ViewFlags vflags, GUIProfile *guiprof, KMixWindow *dockW )
     : ViewBase(parent, name, mixer, /*Qt::FramelessWindowHint | Qt::MSWindowsFixedSizeDialogHint*/0, vflags, guiprof), _dock(dockW)
 {
+    //_layoutControls = new QHBoxLayout(this);
     _layoutMDW = new QGridLayout( this );
     _layoutMDW->setSpacing( KDialog::spacingHint() );
     _layoutMDW->setMargin(0);
     _layoutMDW->setObjectName( QLatin1String( "KmixPopupLayout" ) );
+    //_layoutMDW->addItem(_layoutControls);
     setMixSet();
 }
 
@@ -65,17 +67,6 @@ void ViewDockAreaPopup::wheelEvent ( QWheelEvent * e ) {
       QApplication::sendEvent( mdw, e);
 }
 
-MixDevice* ViewDockAreaPopup::dockDevice()
-{
-   MixDeviceWidget* mdw = 0;
-   if ( !_mdws.isEmpty() )
-      mdw = (MixDeviceWidget*)_mdws.first();
-
-   if ( mdw != 0 )
-      return mdw->mixDevice();
-   return (MixDevice*)(0);
-}
-
 
 void ViewDockAreaPopup::showContextMenu()
 {
@@ -88,6 +79,7 @@ void ViewDockAreaPopup::_setMixSet()
 {
    // kDebug(67100) << "ViewDockAreaPopup::setMixSet()\n";
 
+  // -- remove controls
    if ( _mixer->isDynamic() ) {
       // Our _layoutMDW now should only contain spacer widgets from the QSpacerItem's in add() below.
       // We need to trash those too otherwise all sliders gradually migrate away from the edge :p
@@ -106,7 +98,31 @@ void ViewDockAreaPopup::_setMixSet()
    if ( dockMD != 0 ) {
       _mixSet->append(dockMD);
    }
+   
+   Mixer* mixer2;
+   foreach ( mixer2 , Mixer::mixers() )
+   {
+   MixDevice *md;
+   foreach ( md, mixer2->getMixSet() )
+   {
+     if (md->isApplicationStream())
+     {
+      _mixSet->append(md);
+      kDebug(67100) << "Add to tray popup: " << md->id();
+     }
+   }
 }
+   
+}
+
+
+void ViewDockAreaPopup::controlsReconfigured( const QString& mixer_ID )
+{
+	kDebug(67100) << "RECONFIGURE AND RECREATE DOCK";
+	ViewBase::controlsReconfigured(mixer_ID);
+	emit recreateMe();
+}
+
 
 QWidget* ViewDockAreaPopup::add(MixDevice *md)
 {
@@ -118,56 +134,39 @@ QWidget* ViewDockAreaPopup::add(MixDevice *md)
       true,         // Show Mute LED
       false,        // Show Record LED
       false,        // Small
-      Qt::Vertical, // Direction: only 1 device, so doesn't matter
+      Qt::Horizontal, // Direction: only 1 device, so doesn't matter
       this,         // parent
       0             // Is "NULL", so that there is no RMB-popup
       , pctl
    );
-   _layoutMDW->addItem( new QSpacerItem( 5, 20 ), 0, 2 );
-   _layoutMDW->addItem( new QSpacerItem( 5, 20 ), 0, 0 );
-   _layoutMDW->addWidget( mdw, 0, 1 );
-
-   // Add button to show main panel
-   QPushButton *pb = new QPushButton( i18n("Mixer"), this );
-   pb->setObjectName( QLatin1String("MixerPanel" ));
-   connect ( pb, SIGNAL( clicked() ), SLOT( showPanelSlot() ) );
-   _layoutMDW->addWidget( pb, 1, 0, 1, 3 );
+   int sliderColumn = _layoutMDW->rowCount();
+   if (sliderColumn == 1 ) sliderColumn =0;
+   _layoutMDW->addItem( new QSpacerItem( 5, 20 ), sliderColumn,0 );
+   _layoutMDW->addWidget( mdw, sliderColumn+1,0 );
 
+   //kDebug(67100) << "ADDED " << md->id() << " at column " << sliderColumn;
    return mdw;
 }
 
 void ViewDockAreaPopup::constructionFinished() {
    //    kDebug(67100) << "ViewDockAreaPopup::constructionFinished()\n";
-   QWidget* mdw = 0;
-   if ( !_mdws.isEmpty() )
-      mdw = _mdws.first();
 
-   if ( mdw != 0 ) {
-      mdw->move(0,0);
-      mdw->show();
-   }
+   int sliderColumn = _layoutMDW->rowCount();
+  _layoutMDW->addItem( new QSpacerItem( 5, 20 ), sliderColumn, 0 ); // TODO add this on "polish()"
+   QPushButton *pb = new QPushButton( i18n("Mixer"), this );
+   pb->setObjectName( QLatin1String("MixerPanel" ));
+   connect ( pb, SIGNAL(clicked()), SLOT(showPanelSlot()) );
+   _layoutMDW->addWidget( pb, sliderColumn+1, 0, 1, 1 );
 }
 
 
 void ViewDockAreaPopup::refreshVolumeLevels() {
-   //    kDebug(67100) << "ViewDockAreaPopup::refreshVolumeLevels()\n";
-   QWidget* mdw = 0;
-   if ( !_mdws.isEmpty() )
-      mdw = _mdws.first();
-
-   if ( mdw == 0 ) {
-      kError(67100) << "ViewDockAreaPopup::refreshVolumeLevels(): mdw == 0\n";
-      // sanity check (normally the lists are set up correctly)
-   }
-   else {
-      if ( mdw->inherits("MDWSlider")) { // sanity check
-            static_cast<MDWSlider*>(mdw)->update();
-      }
-      else {
-         kError(67100) << "ViewDockAreaPopup::refreshVolumeLevels(): mdw is not slider\n";
-         // no slider. Cannot happen in theory => skip it
-      }
-   }
+  foreach ( QWidget* qw, _mdws )
+  {
+    //kDebug() << "rvl: " << qw;
+    MixDeviceWidget* mdw = qobject_cast<MixDeviceWidget*>(qw);
+    if ( mdw != 0 ) mdw->update();
+  }
 }
 
 void ViewDockAreaPopup::showPanelSlot() {
