@@ -36,15 +36,12 @@ class ViewDockAreaPopup : public ViewBase
 public:
     ViewDockAreaPopup(QWidget* parent, const char* name, Mixer* mixer, ViewBase::ViewFlags vflags, GUIProfile *guiprof, KMixWindow *dockW);
     ~ViewDockAreaPopup();
-    MixDevice* dockDevice();
 
     virtual QWidget* add(MixDevice *mdw);
     virtual void constructionFinished();
     virtual void refreshVolumeLevels();
     virtual void showContextMenu();
 
-    //QSize sizeHint() const;
-
 protected:
     KMixWindow  *_dock;
 
@@ -52,10 +49,17 @@ protected:
     virtual void _setMixSet();
 
 private:
-    QGridLayout* _layoutMDW;
+  QLayout* _layoutControls;
+  QGridLayout* _layoutMDW;
 
+public slots:
+   virtual void controlsReconfigured( const QString& mixer_ID );
 private slots:
     void showPanelSlot();
+signals:
+    void recreateMe();
+
+
 
 };
 
